--
-- Migrate GH Tester database from schema version 1.9.20 to 1.9.21
--

DECLARE 
  required_version VARCHAR2(100);
  current_version VARCHAR2(100);
BEGIN
  SELECT '1.9.20' INTO required_version FROM dual;
  SELECT value INTO current_version FROM db_details 
    WHERE property='schema.version.number' 
    AND ctime = (
      SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number' 
    );
    
   IF current_version != required_version THEN
     RAISE_APPLICATION_ERROR( -20001, 
                             'Incorrect schema version: ' || current_version  ||
                             ', expected: ' || required_version );
                             
   ELSE
-- 
-- Update Script here
--
EXECUTE IMMEDIATE 'ALTER TABLE "DETAIL_EXECUTION" RENAME TO "DE"';
EXECUTE IMMEDIATE 'ALTER TABLE "DE" DROP CONSTRAINT "DETAIL_EXECUTION_PK"';

EXECUTE IMMEDIATE
'CREATE TABLE "DETAIL_EXECUTION"(
    "APPMODELITEM_ID"      NUMBER(19, 0)    NOT NULL,
    "EXECUTION_ID"         NUMBER(19, 0)    NOT NULL,
    "ACTION_EXECUTION_ID"  NUMBER(19, 0),
    "STATUS_ID"            NUMBER(10, 0),
    "USERNAME"             VARCHAR2(50),
    "HOSTNAME"             VARCHAR2(100),
    "TOTAL_ITERATIONS"     NUMBER(10, 0),
    "FAILED_ITERATIONS"    VARCHAR2(500),
    "FAILED_COUNT"         NUMBER(10, 0),
    CONSTRAINT "DETAIL_EXECUTION_PK" PRIMARY KEY ("EXECUTION_ID"), 
    FOREIGN KEY ("ACTION_EXECUTION_ID")
    REFERENCES "ACTION_EXECUTION"("ID"),
    FOREIGN KEY ("STATUS_ID")
    REFERENCES "STATUS"("ID"),
    FOREIGN KEY ("APPMODELITEM_ID")
    REFERENCES "APPMODELITEM"("ID") ON DELETE CASCADE,
    FOREIGN KEY ("EXECUTION_ID")
    REFERENCES "EXECUTION"("ID") ON DELETE CASCADE
)';

EXECUTE IMMEDIATE 'INSERT INTO "DETAIL_EXECUTION" SELECT * FROM "DE"';
commit;
EXECUTE IMMEDIATE 'DROP TABLE "DE"';

EXECUTE IMMEDIATE 'ALTER TABLE "SCENARIO_EXECUTION" RENAME TO "SE"';
EXECUTE IMMEDIATE 'ALTER TABLE "SE" DROP CONSTRAINT "SCENARIO_EXECUTION_PK"';

EXECUTE IMMEDIATE
'CREATE TABLE "SCENARIO_EXECUTION"(
    "EXECUTION_ID"  NUMBER(19, 0)    NOT NULL,
    "SCENARIO_ID"   NUMBER(19, 0)    NOT NULL,
    CONSTRAINT "SCENARIO_EXECUTION_PK" PRIMARY KEY ("EXECUTION_ID"), 
    FOREIGN KEY ("SCENARIO_ID")
    REFERENCES "SCENARIO"("ID") ON DELETE CASCADE,
    FOREIGN KEY ("EXECUTION_ID")
    REFERENCES "EXECUTION"("ID")
)';

EXECUTE IMMEDIATE 'INSERT INTO "SCENARIO_EXECUTION" SELECT * FROM "SE"';
commit;
EXECUTE IMMEDIATE 'DROP TABLE "SE"';

EXECUTE IMMEDIATE 'ALTER TABLE "EXECUTION_LABEL" RENAME TO "EL"';
EXECUTE IMMEDIATE 'ALTER TABLE "EL" DROP CONSTRAINT "EXECUTION_LABEL_PK"';

EXECUTE IMMEDIATE
'CREATE TABLE "EXECUTION_LABEL" (
    "EXECUTION_ID" NUMBER         NOT NULL, 
    "LABEL"        VARCHAR2(4000) NOT NULL, 
    CONSTRAINT "EXECUTION_LABEL_PK" PRIMARY KEY ("EXECUTION_ID"), 
    FOREIGN KEY ("EXECUTION_ID")
    REFERENCES "EXECUTION" ("ID") ON DELETE CASCADE
)';

EXECUTE IMMEDIATE 'INSERT INTO "EXECUTION_LABEL" SELECT * FROM "EL"';
commit;
EXECUTE IMMEDIATE 'DROP TABLE "EL"';


INSERT INTO db_details VALUES
   ( (SELECT sysdate FROM dual), 'schema.version.number','1.9.21');

commit;

   END IF; -- version check
END;
/