--
-- Migrate GH Tester database from schema version 1.9.23 to 1.9.24
--

DROP PROCEDURE IF EXISTS update_gh_schema;

DELIMITER //
CREATE PROCEDURE update_gh_schema()
BEGIN
  DECLARE current_version varchar(100);
  SET @required_version = '1.9.23';

  SELECT value INTO current_version FROM db_details WHERE 
         property='schema.version.number' AND 
         ctime = (
            SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number'
         );
  IF @required_version != current_version THEN
     SET @version_error = CONCAT( 'Incorrect schema version: ', current_version,
                                  ' expected: ', @required_version );
     SELECT @version_error;
  ELSE

--
-- The update script
--
ALTER TABLE 
    execution
ADD 
    status_id BIGINT NULL
;

ALTER TABLE
    execution
ADD CONSTRAINT fk_execution_status_id
    FOREIGN KEY (status_id)
    REFERENCES status(id)
;    

ALTER TABLE scenario ADD uniqueid VARCHAR(32);
ALTER TABLE scenario ADD appmodelitem_id BIGINT;
ALTER TABLE scenario ADD UNIQUE INDEX `appmodelitem_id`(`appmodelitem_id`, `uniqueid`, `display` );
ALTER TABLE scenario ADD FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE;

COMMIT
;

UPDATE 
    execution 
SET 
    status_id = (SELECT status_id FROM detail_execution d where d.execution_id = execution.id) 
;

CREATE TEMPORARY TABLE
    Temp_detail_execution
(
    `execution_id`         BIGINT          NOT NULL,
    `appmodelitem_id`      BIGINT          NOT NULL,
    `action_execution_id`  BIGINT,
    `username`             VARCHAR(50),
    `hostname`             VARCHAR(100),
    `total_iterations`     BIGINT,
    `failed_iterations`    VARCHAR(500),
`failed_count`         BIGINT
) ENGINE=INNODB
;

INSERT INTO 
    Temp_detail_execution
(
    execution_id, appmodelitem_id, action_execution_id, username, hostname, total_iterations, failed_iterations
)
SELECT 
    execution_id, appmodelitem_id, action_execution_id, username, hostname, total_iterations, failed_iterations
FROM
    detail_execution
;

DROP TABLE detail_execution
;

CREATE TABLE `detail_execution`(
    `execution_id`         BIGINT          NOT NULL,
    `appmodelitem_id`      BIGINT          NOT NULL,
    `action_execution_id`  BIGINT,
    `username`             VARCHAR(50),
    `hostname`             VARCHAR(100),
    `total_iterations`     BIGINT,
    `failed_iterations`    VARCHAR(500),
    `failed_count`         BIGINT,
    PRIMARY KEY (`execution_id`), 
    INDEX `appmodelitem_id`(`appmodelitem_id`),
    INDEX `action_execution_id`(`action_execution_id`), 
    FOREIGN KEY (`action_execution_id`)
    REFERENCES `action_execution`(`id`),
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;

INSERT INTO 
    detail_execution
(
    execution_id, appmodelitem_id, action_execution_id, username, hostname, total_iterations, failed_iterations
)
SELECT 
    execution_id, appmodelitem_id, action_execution_id, username, hostname, total_iterations, failed_iterations
FROM
    Temp_detail_execution
;

INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.24');
   

COMMIT
;
  END IF; -- Schema version check
END
//
DELIMITER ;

CALL update_gh_schema();

DROP PROCEDURE update_gh_schema;