--
-- Migrate GH Tester database from schema version 1.9.24.a to 1.9.24.c
--
DROP PROCEDURE IF EXISTS update_gh_schema;

DELIMITER //
CREATE PROCEDURE update_gh_schema()
BEGIN
  DECLARE current_version varchar(100);
  SET @required_version = '1.9.24.a';

  SELECT value INTO current_version FROM db_details WHERE 
         property='schema.version.number' AND 
         ctime = (
            SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number'
         );
  IF @required_version != current_version THEN
     SET @version_error = CONCAT( 'Incorrect schema version: ', current_version,
                                  ' expected: ', @required_version );
     SELECT @version_error;
  ELSE

--
-- The update script
--

ALTER TABLE 
    execution
ADD 
    root_id BIGINT NULL
;

ALTER TABLE 
    execution
ADD 
    environment BIGINT NULL
;

ALTER TABLE
    execution
ADD CONSTRAINT execution_rootid_fk
    FOREIGN KEY (root_id)
    REFERENCES execution(id)
;

ALTER TABLE
    execution
ADD CONSTRAINT execution_environment_fk
    FOREIGN KEY (environment) 
    REFERENCES appmodelitem(id)
; 

CREATE TABLE `test_cycle`(
    `id`            BIGINT         AUTO_INCREMENT,
    `execution_id`  BIGINT         NOT NULL,
    `display`       VARCHAR(255)   NOT NULL,
    `comments`      VARCHAR(4000),
    `is_closed`     CHAR(1)        NOT NULL,
    `created_by`    VARCHAR(255)   NOT NULL,
    `create_date`   BIGINT         NOT NULL,
    `closed_by`     VARCHAR(255),
    `closed_date`   BIGINT,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `test_cycle_unique`(`display`),
    FOREIGN KEY (`execution_id`) 
    REFERENCES `execution`(`id`)
)
;

CREATE TABLE `test_cycle_project`(
    `id`                     BIGINT  AUTO_INCREMENT,
    `test_cycle_id`          BIGINT  NOT NULL,
    `project_id`             BIGINT  NOT NULL,
    `joined_date`            BIGINT  NOT NULL,
    `all_environments`       CHAR(1) NOT NULL,
    `allow_external_tools`   CHAR(1) NOT NULL,
    `is_joined`              CHAR(1) NOT NULL,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `trp_unique`(test_cycle_id, project_id),
    FOREIGN KEY (`test_cycle_id`)
    REFERENCES `test_cycle`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`project_id`)
    REFERENCES `PROJECT`(`id`)
)
;

CREATE TABLE `test_cycle_project_env`(
    `test_cycle_project_id`    BIGINT       NOT NULL,
    `environment`              VARCHAR(255) NOT NULL,
    PRIMARY KEY (`test_cycle_project_id`, `environment` ),
    FOREIGN KEY (`test_cycle_project_id`)
    REFERENCES `test_cycle_project`(`id`) ON DELETE CASCADE
)
;

CREATE TABLE `test_cycle_project_user`(
    `test_cycle_project_id` BIGINT       NOT NULL,
    `username`              VARCHAR(255) NOT NULL,
    `joined_date`           BIGINT       NOT NULL,
    PRIMARY KEY (`TEST_CYCLE_PROJECT_ID`, `USERNAME` ),
    FOREIGN KEY (`test_cycle_project_id`)
    REFERENCES `test_cycle_project`(`id`) ON DELETE CASCADE
)
;

INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.24.c');

commit;

  END IF; -- Schema version check
END
//
DELIMITER ;

CALL update_gh_schema();

DROP PROCEDURE update_gh_schema;

