--
-- Migrate GH Tester database from schema version 1.9.24.a to 1.9.24.c
--

DECLARE 
  required_version VARCHAR2(100);
  current_version VARCHAR2(100);
  index_not_exists EXCEPTION;
PRAGMA EXCEPTION_INIT(index_not_exists, -1418);
BEGIN
  SELECT '1.9.24.a' INTO required_version FROM dual;
  SELECT value INTO current_version FROM db_details 
    WHERE property='schema.version.number' 
    AND ctime = (
      SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number' 
    );
    
   IF current_version != required_version THEN
     RAISE_APPLICATION_ERROR( -20001, 
                             'Incorrect schema version: ' || current_version  ||
                             ', expected: ' || required_version );
                             
   ELSE
-- 
-- Update Script here
--

-- Remove adhoc indices
begin
execute immediate ('DROP INDEX RVHI_TS_RVHI_MRV_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_3_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_5_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_7_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_MRV_ATTR_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_TOPIC_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMIS_SERVER_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_ET_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_B_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_SEQ_END_TS_EXECUTION_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_SEQ_END_MRV_APPMODEL_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_TRANS_MRV_TESTEN_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_ENGINE_TS_TESTEN_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SUITE_EXECUTION_ACTION_EXEC_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DT_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DQMEMBER_TS_DQMEMBER_MRV_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_RETRANS_TS_EXECUTIO_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_PTP_TS_RVTRACE_PTP_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_1_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMIS_SERVICE_MRV_WMIS_SERVE_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_CG_TS_WMBROKER_CG_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TRANS_HISTORY_TRANS_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_SEQ_END_TS_TESTER_SE_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SYSSTAT_SYS_STATS_TS_EXECUT_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_CONNS_TS_SONIC_CONNS_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_BROKER_TS_SONIC_BROKE_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DETAIL_EXECUTION_ACTION_EXE_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX BWPROC_TS_BWPROC_MRV_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX BWHOST_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EXECUTION_PARENT_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX ACTION_ACTIONTYPE_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX APPMODELITEM_APPMODELTYPE_I_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_NETWORK_TS_RVTRAC_N_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_6_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EXECUTION_LOCK_PERSON_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_C_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_B_TS_WMBROKER_B_MR_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_TRANS_END_MRV_APPMOD_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_SEQ_MRV_TESTENGI_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_CONNS_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_ROUTE_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DT_HISTORY_DT_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX BWPROC_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX BWACTIVITY_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX APPMODELITEM_PARENT_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SCENARIO_EXECUTION_SCENARIO_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_LOGMEASUR_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_STRCTR_3_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_STRCTR_4_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_MRV_ATTR_I_1_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_MRV_ATTR_I_3_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_MRV_ATTR_I_4_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_ET_MRV_WMBROKER_B__FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TRANS_HISTORY_ITER_HIST_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_TRANS_MRV_APPMODELIT_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_SEQ_TS_TESTER_SEQ_MR_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_QUEUE_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_SERVER_TS_EMS_SERVER_MR_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_QUEUE_TS_EMS_QUEUE_MRV_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DQGROUP_TS_DQGROUP_MRV_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DETAIL_EXECUTION_APPMODELIT_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_SUBJECT_TS_RVTRACE_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX PERFORM_CHARTS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_EXECUTION_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_2_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_C_MRV_WMBROKER_B_M_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_TRANS_TS_TESTER_TRAN_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_TRANS_END_TS_EXECUTI_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_TRANS_TS_TESTENG_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SYSSTAT_PROC_STATS_TS_EXECU_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SUITE_EXECUTION_APPMODELITE_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_BROKER_TS_EXECUTION_I_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_SERVER_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DQMEMBER_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX BWHOST_TS_BWHOST_MRV_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX ACTION_EXECUTION_ACTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_SUBJECT_TS_EXECUTIO_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_MULTICAST_TS_RVTRAC_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVHI_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX PERFORM_EXECUTION_APPMODELI_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX PERFORM_CHARTS_PROJECT_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_8_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_STRCTR_1_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX ITER_HISTORY_DT_HIST_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX FLEX_LONG_EVENT_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_TOPIC_TS_EMS_TOPIC_MRV_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMIS_SERVER_TS_WMIS_SERVER_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_ET_TS_WMBROKER_ET_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_CG_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_CG_MRV_WMBROKER_B_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_SEQ_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_ENGINE_TS_EXECUT_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SYSSTAT_SYS_STATS_TS_SYSSTA_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SYSSTAT_PROC_STATS_TS_SYSST_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DQGROUP_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX BWACTIVITY_TS_BWACTIVITY_MR_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_AGENT_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_RETRANS_TS_RVTRACE_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_PTP_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_MULTICAST_TS_EXECUT_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_CTR_ID_4_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_MRV_ATTR_I_5_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMIS_SERVICE_TS_WMIS_SERVIC_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMIS_SERVICE_TS_EXECUTION_I_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX WMBROKER_C_TS_WMBROKER_C_MR_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_TRANS_END_TS_TESTER__FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_TRANS_TS_EXECUTI_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX COVERAGE_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_AGENT_TS_SONIC_AGENT__FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX RVTRACE_NETWORK_TS_EXECUTIO_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX LOGMEASUREMENT_TS_STRCTR_2_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX FLEX_DOUBLE_EVENT_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_TRANS_TS_EXECUTION_I_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTER_SEQ_MRV_APPMODELITEM_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_SEQ_TS_EXECUTION_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX TESTENGINE_SEQ_TS_TESTENGIN_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX SONIC_QUEUE_TS_SONIC_QUEUE__FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_ROUTE_TS_EMS_ROUTE_MRV_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX EMS_QUEUE_TS_EXECUTION_ID_FK');
exception
when index_not_exists then
null;
end;

begin
execute immediate ('DROP INDEX DT_HISTORY_AGENT_ID_FK');
exception
when index_not_exists then
null;
end;


-- Table changes
EXECUTE IMMEDIATE 'ALTER TABLE EXECUTION ADD "ROOT_ID" NUMBER(19,0) NULL';
EXECUTE IMMEDIATE 'ALTER TABLE EXECUTION ADD "ENVIRONMENT" NUMBER(19,0) NULL';
EXECUTE IMMEDIATE 'ALTER TABLE EXECUTION ADD CONSTRAINT "EXECUTION_APPMODELITEM_FK1" FOREIGN KEY ("ENVIRONMENT") REFERENCES "APPMODELITEM" ("ID")';
EXECUTE IMMEDIATE 'ALTER TABLE EXECUTION ADD CONSTRAINT "EXECUTION_EXECUTION_FK1" FOREIGN KEY ("ROOT_ID") REFERENCES "EXECUTION" ("ID")';

-- Add missing indices';
EXECUTE IMMEDIATE 'CREATE INDEX ACTION_ACTIONTYPEID_FK ON ACTION (ACTIONTYPE_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX ACTION_EXECUTION_ACTIONID_FK ON ACTION_EXECUTION (ACTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX APPMODELITEM_APPMODELTYPEID_FK ON APPMODELITEM (APPMODELTYPE_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX APPMODELITEM_PARENTID_FK ON APPMODELITEM (PARENT_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX BWACTIVITY_TS_EXECUTIONID_FK ON BWACTIVITY_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX BWACTIVITY_TS_BWACTIVITYMRV_FK ON BWACTIVITY_TS (BWACTIVITY_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX BWHOST_TS_EXECUTIONID_FK ON BWHOST_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX BWHOST_TS_BWHOSTMRVID_FK ON BWHOST_TS (BWHOST_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX BWPROC_TS_EXECUTIONID_FK ON BWPROC_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX BWPROC_TS_BWPROCMRVID_FK ON BWPROC_TS (BWPROC_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX COVERAGE_EXECUTIONID_FK ON COVERAGE (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DETAIL_EXECUTION_ACTIONEXEC_FK ON DETAIL_EXECUTION (ACTION_EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DETAIL_EXECUTION_APPMODELIT_FK ON DETAIL_EXECUTION (APPMODELITEM_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DQGROUP_TS_EXECUTIONID_FK ON DQGROUP_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DQGROUP_TS_DQGROUPMRVID_FK ON DQGROUP_TS (DQGROUP_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DQMEMBER_TS_EXECUTIONID_FK ON DQMEMBER_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DQMEMBER_TS_DQMEMBERMRVID_FK ON DQMEMBER_TS (DQMEMBER_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DT_EXECUTIONID_FK ON DT (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DT_HISTORY_AGENTID_FK ON DT_HISTORY (AGENT_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX DT_HISTORY_DTID_FK ON DT_HISTORY (DT_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_QUEUE_TS_EXECUTIONID_FK ON EMS_QUEUE_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_QUEUE_TS_EMSQUEUEMRVID_FK ON EMS_QUEUE_TS (EMS_QUEUE_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_ROUTE_TS_EXECUTIONID_FK ON EMS_ROUTE_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_ROUTE_TS_EMSROUTEMRVID_FK ON EMS_ROUTE_TS (EMS_ROUTE_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_SERVER_TS_EXECUTIONID_FK ON EMS_SERVER_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_SERVER_TS_EMSSERVERMRVI_FK ON EMS_SERVER_TS (EMS_SERVER_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_TOPIC_TS_EXECUTIONID_FK ON EMS_TOPIC_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EMS_TOPIC_TS_EMSTOPICMRVID_FK ON EMS_TOPIC_TS (EMS_TOPIC_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EXECUTION_PARENTID_FK ON EXECUTION (PARENT_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EXECUTION_STATUSID_FK ON EXECUTION (STATUS_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EXECUTION_ROOTID_FK ON EXECUTION (ROOT_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX EXECUTION_ENVIRONMENT_FK ON EXECUTION (ENVIRONMENT)';
EXECUTE IMMEDIATE 'CREATE INDEX EXECUTION_LOCK_PERSONID_FK ON EXECUTION_LOCK (PERSON_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX FLEX_DOUBLE_EVENT_FK ON FLEX_DOUBLE (EVENT)';
EXECUTE IMMEDIATE 'CREATE INDEX FLEX_LONG_EVENT_FK ON FLEX_LONG (EVENT)';
EXECUTE IMMEDIATE 'CREATE INDEX ITER_HISTORY_DTHISTID_FK ON ITER_HISTORY (DT_HIST_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_MRV_ATTRID1_FK ON LOGMEASUREMENT_MRV (ATTR_ID_1)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_MRV_ATTRID2_FK ON LOGMEASUREMENT_MRV (ATTR_ID_2)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_MRV_ATTRID3_FK ON LOGMEASUREMENT_MRV (ATTR_ID_3)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_MRV_ATTRID4_FK ON LOGMEASUREMENT_MRV (ATTR_ID_4)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_MRV_ATTRID5_FK ON LOGMEASUREMENT_MRV (ATTR_ID_5)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_EXECUTION_FK ON LOGMEASUREMENT_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_LOGMEASUR_FK ON LOGMEASUREMENT_TS (LOGMEASUREMENT_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID1_FK ON LOGMEASUREMENT_TS (CTR_ID_1)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID2_FK ON LOGMEASUREMENT_TS (CTR_ID_2)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID3_FK ON LOGMEASUREMENT_TS (CTR_ID_3)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID4_FK ON LOGMEASUREMENT_TS (CTR_ID_4)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID5_FK ON LOGMEASUREMENT_TS (CTR_ID_5)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID6_FK ON LOGMEASUREMENT_TS (CTR_ID_6)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID7_FK ON LOGMEASUREMENT_TS (CTR_ID_7)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_CTRID8_FK ON LOGMEASUREMENT_TS (CTR_ID_8)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_STRCTRID1_FK ON LOGMEASUREMENT_TS (STRCTR_ID_1)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_STRCTRID2_FK ON LOGMEASUREMENT_TS (STRCTR_ID_2)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_STRCTRID3_FK ON LOGMEASUREMENT_TS (STRCTR_ID_3)';
EXECUTE IMMEDIATE 'CREATE INDEX LOGMEASUREMENT_TS_STRCTRID4_FK ON LOGMEASUREMENT_TS (STRCTR_ID_4)';
EXECUTE IMMEDIATE 'CREATE INDEX PERFORM_CHARTS_PROJECTID_FK ON PERFORM_CHARTS (PROJECT_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX PERFORM_CHARTS_EXECUTIONID_FK ON PERFORM_CHARTS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX PERFORM_EXECUTION_APPMODELI_FK ON PERFORM_EXECUTION (APPMODELITEM_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVHI_TS_EXECUTIONID_FK ON RVHI_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVHI_TS_RVHIMRVID_FK ON RVHI_TS (RVHI_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_MULTICAST_TS_EXECUT_FK ON RVTRACE_MULTICAST_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_MULTICAST_TS_RVTRAC_FK ON RVTRACE_MULTICAST_TS (RVTRACE_MULTICAST_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_NETWORK_TS_EXECUTIO_FK ON RVTRACE_NETWORK_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_NETWORK_TS_RVTRACEN_FK ON RVTRACE_NETWORK_TS (RVTRACE_NETWORK_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_PTP_TS_EXECUTIONID_FK ON RVTRACE_PTP_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_PTP_TS_RVTRACEPTPMR_FK ON RVTRACE_PTP_TS (RVTRACE_PTP_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_RETRANS_TS_EXECUTIO_FK ON RVTRACE_RETRANS_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_RETRANS_TS_RVTRACER_FK ON RVTRACE_RETRANS_TS (RVTRACE_RETRANS_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_SUBJECT_TS_EXECUTIO_FK ON RVTRACE_SUBJECT_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX RVTRACE_SUBJECT_TS_RVTRACES_FK ON RVTRACE_SUBJECT_TS (RVTRACE_SUBJECT_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SCENARIO_EXECUTION_SCENARIO_FK ON SCENARIO_EXECUTION (SCENARIO_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_AGENT_TS_EXECUTIONID_FK ON SONIC_AGENT_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_AGENT_TS_SONICAGENTMR_FK ON SONIC_AGENT_TS (SONIC_AGENT_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_BROKER_TS_EXECUTIONID_FK ON SONIC_BROKER_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_BROKER_TS_SONICBROKER_FK ON SONIC_BROKER_TS (SONIC_BROKER_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_CONNS_TS_EXECUTIONID_FK ON SONIC_CONNS_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_CONNS_TS_SONICCONNSMR_FK ON SONIC_CONNS_TS (SONIC_CONNS_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_QUEUE_TS_EXECUTIONID_FK ON SONIC_QUEUE_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SONIC_QUEUE_TS_SONICQUEUEMR_FK ON SONIC_QUEUE_TS (SONIC_QUEUE_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SUITE_EXECUTION_ACTIONEXECU_FK ON SUITE_EXECUTION (ACTION_EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SUITE_EXECUTION_APPMODELITE_FK ON SUITE_EXECUTION (APPMODELITEM_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SYSSTAT_PROC_STATS_TS_EXECU_FK ON SYSSTAT_PROC_STATS_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SYSSTAT_PROC_STATS_TS_SYSST_FK ON SYSSTAT_PROC_STATS_TS (SYSSTAT_PROC_STATS_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SYSSTAT_SYS_STATS_TS_EXECUT_FK ON SYSSTAT_SYS_STATS_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX SYSSTAT_SYS_STATS_TS_SYSSTA_FK ON SYSSTAT_SYS_STATS_TS (SYSSTAT_SYS_STATS_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_ENGINE_TS_EXECUT_FK ON TESTENGINE_ENGINE_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_ENGINE_TS_TESTEN_FK ON TESTENGINE_ENGINE_TS (TESTENGINE_ENGINE_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_SEQ_MRV_TESTENGI_FK ON TESTENGINE_SEQ_MRV (TESTENGINE_ENGINE_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_SEQ_TS_EXECUTION_FK ON TESTENGINE_SEQ_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_SEQ_TS_TESTENGIN_FK ON TESTENGINE_SEQ_TS (TESTENGINE_SEQ_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_TRANS_MRV_TESTEN_FK ON TESTENGINE_TRANS_MRV (TESTENGINE_ENGINE_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_TRANS_TS_EXECUTI_FK ON TESTENGINE_TRANS_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTENGINE_TRANS_TS_TESTENG_FK ON TESTENGINE_TRANS_TS (TESTENGINE_TRANS_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_SEQ_END_MRV_APPMODEL_FK ON TESTER_SEQ_END_MRV (APPMODELITEM_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_SEQ_END_TS_EXECUTION_FK ON TESTER_SEQ_END_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_SEQ_END_TS_TESTERSEQ_FK ON TESTER_SEQ_END_TS (TESTER_SEQ_END_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_SEQ_MRV_APPMODELITEM_FK ON TESTER_SEQ_MRV (APPMODELITEM_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_SEQ_TS_EXECUTIONID_FK ON TESTER_SEQ_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_SEQ_TS_TESTERSEQMRVI_FK ON TESTER_SEQ_TS (TESTER_SEQ_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_TRANS_END_MRV_APPMOD_FK ON TESTER_TRANS_END_MRV (APPMODELITEM_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_TRANS_END_TS_EXECUTI_FK ON TESTER_TRANS_END_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_TRANS_END_TS_TESTERT_FK ON TESTER_TRANS_END_TS (TESTER_TRANS_END_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_TRANS_MRV_APPMODELIT_FK ON TESTER_TRANS_MRV (APPMODELITEM_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_TRANS_TS_EXECUTIONID_FK ON TESTER_TRANS_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TESTER_TRANS_TS_TESTERTRANS_FK ON TESTER_TRANS_TS (TESTER_TRANS_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TRANS_HISTORY_TRANSID_FK ON TRANS_HISTORY (TRANS_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX TRANS_HISTORY_ITERHISTID_FK ON TRANS_HISTORY (ITER_HIST_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_B_TS_WMBROKERBMRVI_FK ON WMBROKER_B_TS (WMBROKER_B_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_B_TS_EXECUTIONID_FK ON WMBROKER_B_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_CG_MRV_WMBROKERBMR_FK ON WMBROKER_CG_MRV (WMBROKER_B_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_CG_TS_WMBROKERCGMR_FK ON WMBROKER_CG_TS (WMBROKER_CG_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_CG_TS_EXECUTIONID_FK ON WMBROKER_CG_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_C_MRV_WMBROKERBMRV_FK ON WMBROKER_C_MRV (WMBROKER_B_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_C_TS_WMBROKERCMRVI_FK ON WMBROKER_C_TS (WMBROKER_C_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_C_TS_EXECUTIONID_FK ON WMBROKER_C_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_ET_MRV_WMBROKERBMR_FK ON WMBROKER_ET_MRV (WMBROKER_B_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_ET_TS_WMBROKERETMR_FK ON WMBROKER_ET_TS (WMBROKER_ET_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMBROKER_ET_TS_EXECUTIONID_FK ON WMBROKER_ET_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMIS_SERVER_TS_WMISSERVERMR_FK ON WMIS_SERVER_TS (WMIS_SERVER_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMIS_SERVER_TS_EXECUTIONID_FK ON WMIS_SERVER_TS (EXECUTION_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMIS_SERVICE_MRV_WMISSERVER_FK ON WMIS_SERVICE_MRV (WMIS_SERVER_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMIS_SERVICE_TS_WMISSERVICE_FK ON WMIS_SERVICE_TS (WMIS_SERVICE_MRV_ID)';
EXECUTE IMMEDIATE 'CREATE INDEX WMIS_SERVICE_TS_EXECUTIONID_FK ON WMIS_SERVICE_TS (EXECUTION_ID)';

EXECUTE IMMEDIATE
'CREATE SEQUENCE TEST_CYCLE_SEQ
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    CACHE 20
    NOORDER
';

EXECUTE IMMEDIATE
'CREATE SEQUENCE TEST_CYCLE_PROJECT_SEQ
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    CACHE 20
    NOORDER
';

EXECUTE IMMEDIATE
  'CREATE TABLE "TEST_CYCLE"(
    "ID"    NUMBER(19, 0)    NOT NULL,
    "EXECUTION_ID"  NUMBER(19, 0)    NOT NULL,
    "DISPLAY"   VARCHAR2(255)    NOT NULL,
    "COMMENTS"   VARCHAR2(4000),
    "IS_CLOSED"   CHAR(1)    NOT NULL,
    "CREATED_BY"   VARCHAR2(255)    NOT NULL,
    "CREATE_DATE"  NUMBER(20, 0)    NOT NULL,
    "CLOSED_BY"   VARCHAR2(255),
    "CLOSED_DATE"  NUMBER(20, 0),
    CONSTRAINT "TEST_CYCLE_PK" PRIMARY KEY ("ID"),
    CONSTRAINT TEST_CYCLE_UNIQUE UNIQUE ("DISPLAY"),
    FOREIGN KEY ("EXECUTION_ID") 
    REFERENCES "EXECUTION"("ID")
)';

EXECUTE IMMEDIATE
  'CREATE TABLE "TEST_CYCLE_PROJECT"(
    "ID"    NUMBER(19, 0)    NOT NULL,
    "TEST_CYCLE_ID"    NUMBER(19, 0)    NOT NULL,
    "PROJECT_ID"   NUMBER(19, 0)    NOT NULL,
    "JOINED_DATE"  NUMBER(20, 0)    NOT NULL,
    "ALL_ENVIRONMENTS"   CHAR(1)    NOT NULL,
    "ALLOW_EXTERNAL_TOOLS"   CHAR(1)    NOT NULL,
    "IS_JOINED"   CHAR(1)    NOT NULL,
    CONSTRAINT "TEST_CYCLE_PROJECT_PK" PRIMARY KEY ("ID"),
    CONSTRAINT TRP_UNIQUE UNIQUE (TEST_CYCLE_ID, PROJECT_ID),
    FOREIGN KEY ("TEST_CYCLE_ID")
    REFERENCES "TEST_CYCLE"("ID") ON DELETE CASCADE,
    FOREIGN KEY ("PROJECT_ID")
    REFERENCES "PROJECT"("ID")
)';

EXECUTE IMMEDIATE
  'CREATE TABLE "TEST_CYCLE_PROJECT_ENV"(
    "TEST_CYCLE_PROJECT_ID"    NUMBER(19, 0)    NOT NULL,
    "ENVIRONMENT"   VARCHAR2(255)    NOT NULL,
    CONSTRAINT "TEST_CYCLE_PROJECT_ENV_PK" PRIMARY KEY ("TEST_CYCLE_PROJECT_ID", "ENVIRONMENT" ),
    FOREIGN KEY ("TEST_CYCLE_PROJECT_ID")
    REFERENCES "TEST_CYCLE_PROJECT"("ID") ON DELETE CASCADE
)';

EXECUTE IMMEDIATE
  'CREATE TABLE "TEST_CYCLE_PROJECT_USER"(
    "TEST_CYCLE_PROJECT_ID"    NUMBER(19, 0)    NOT NULL,
    "USERNAME"   VARCHAR2(255)    NOT NULL,
    "JOINED_DATE"  NUMBER(20, 0)    NOT NULL,
    CONSTRAINT "TEST_CYCLE_PROJECT_USR_PK" PRIMARY KEY ("TEST_CYCLE_PROJECT_ID", "USERNAME" ),
    FOREIGN KEY ("TEST_CYCLE_PROJECT_ID")
    REFERENCES "TEST_CYCLE_PROJECT"("ID") ON DELETE CASCADE
)';


INSERT INTO db_details VALUES
   ( (SELECT sysdate FROM dual), 'schema.version.number','1.9.24.c');

commit;

   END IF; -- version check
END;
/